@@ -1,3 +1,5 @@
+"""This module defines object specific to Windows platform."""
+
 import sys
 import platform
 
@@ -5,6 +7,7 @@ from . import abstract
 
 
 class WindowsPlatform(abstract.CMakePlatform):
+    """Windows implementation of :class:`.abstract.CMakePlatform`."""
 
     def __init__(self):
         super(WindowsPlatform, self).__init__()
@@ -35,14 +38,9 @@ class WindowsPlatform(abstract.CMakePlatform):
             raise RuntimeError("Only Python >= 2.7 is supported on Windows.")
 
         # Python is Win64, build a Win64 module
-        if platform.architecture() == "x64":
+        if platform.architecture()[0] == "64bit":
             vs_base += " Win64"
 
-        # only VS 11 and above support ARM, but include it here in hopes of
-        # making future work easier.
-        elif platform.architecture() == "ARM":
-            vs_base += " ARM"
-
         # we're implicitly doing nothing for 32-bit builds.  Their generator
         # string IDs seem to be just the vs_base.
 
