@@ -6,6 +6,5 @@ setup(
     description="a minimal example package",
     author='The scikit-build team',
     license="MIT",
-    packages=['hello'],
-    package_dir={'hello': 'hello'},
+    packages=['bonjour', 'hello'],
 )
