@@ -8,8 +8,13 @@ Tests for platforms, to verify that CMake correctly does a test compilation.
 """
 
 import os
+import pytest
 
 from skbuild.platform_specifics import get_platform
+from skbuild.utils import mkdir_p
+
+# XXX This should probably be a constant imported from skbuild.constants
+test_folder = "_cmake_test_compile"
 
 # platform is shared across each test.  It's a platform-specific object
 # that defines default CMake generator strings.
@@ -27,7 +32,7 @@ def test_write_compiler_test_file():
     try:
         # verify that the test file exists (it's not valid, because it has no
         # languages)
-        assert(os.path.exists("cmake_test_compile/CMakeLists.txt"))
+        assert(os.path.exists(os.path.join(test_folder, "CMakeLists.txt")))
     except:
         raise
     finally:
@@ -35,7 +40,13 @@ def test_write_compiler_test_file():
 
 
 def test_cxx_compiler():
-    generator = platform.get_best_generator(languages=["CXX", "C"])
+
+    # Create a unique subdirectory 'foo' that is expected to be removed.
+    test_build_folder = os.path.join(test_folder, 'build', 'foo')
+    mkdir_p(test_build_folder)
+
+    generator = platform.get_best_generator(languages=["CXX", "C"],
+                                            cleanup=False)
     # TODO: this isn't a true unit test.  It depends on the test CMakeLists.txt
     #       file having been written correctly.
     # with the known test file present, this tries to generate a makefile
@@ -44,12 +55,14 @@ def test_cxx_compiler():
     # doesn't actually compile anything.
     try:
         assert(generator is not None)
+        assert not os.path.exists(test_build_folder)
     except:
         raise
     finally:
         platform.cleanup_test()
 
 
+@pytest.mark.fortran
 def test_fortran_compiler():
     generator = platform.get_best_generator(languages=["Fortran"])
     # TODO: this isn't a true unit test.  It depends on the test
@@ -69,4 +82,33 @@ def test_fortran_compiler():
 def test_generator_cleanup():
     # TODO: this isn't a true unit test.  It is checking that none of the
     # other tests have left a mess.
-    assert(not os.path.exists("cmake_test_compile"))
+    assert(not os.path.exists(test_folder))
+
+
+@pytest.mark.parametrize("supported_platform",
+                         ['darwin', 'freebsd', 'linux', 'windows'])
+def test_known_platform(supported_platform, mocker):
+    mocker.patch('platform.system', return_value=supported_platform)
+    platforms = {
+        'freebsd': 'BSD',
+        'linux': 'Linux',
+        'darwin': 'OSX',
+        'windows': 'Windows'
+    }
+    expected_platform_classname = "%sPlatform" % platforms[supported_platform]
+    assert get_platform().__class__.__name__ == expected_platform_classname
+
+
+def test_unsupported_platform(mocker):
+    mocker.patch('platform.system', return_value='bogus')
+
+    failed = False
+    message = ""
+    try:
+        get_platform()
+    except RuntimeError as e:
+        failed = True
+        message = str(e)
+
+    assert failed
+    assert "Unsupported platform: bogus." in message
